SeilonSdkConfig class final

Constructors

SeilonSdkConfig({String? accountId, Duration? commandTimeout, Duration? wifiCommandTimeout, Duration? networkTimeout, Duration? transferIdleTimeout, String? defaultTcpHost, int? defaultTcpPort, int? maxLogEntries})
const

Properties

accountId String?
final
commandTimeout Duration?
final
defaultTcpHost String?
final
defaultTcpPort int?
final
hashCode int
The hash code for this object.
no setterinherited
maxLogEntries int?
final
networkTimeout Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferIdleTimeout Duration?
final
wifiCommandTimeout Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited