MethodChannelSeilonVoicePlugin class
- Inheritance
-
- Object
- PlatformInterface
- SeilonVoicePluginPlatform
- MethodChannelSeilonVoicePlugin
Constructors
Properties
- eventChannel → EventChannel
-
final
-
events
→ Stream<
SeilonSdkEvent> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPermissions(
SeilonPermissionOperation operation) → Future< SeilonPermissionReport> -
override
-
clearLogs(
) → Future< void> -
override
-
close(
) → Future< void> -
override
-
connect(
String deviceId) → Future< SeilonSessionHandle> -
override
-
disconnect(
) → Future< void> -
override
-
initialize(
SeilonSdkConfig config) → Future< void> -
override
-
invokeNetwork(
String method, [Map< String, Object?> arguments = const <String, Object?>{}]) → Future<Object?> -
override
-
invokeSession(
String method, int sessionToken, [Map< String, Object?> arguments = const <String, Object?>{}]) → Future<Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermissions(
SeilonPermissionOperation operation) → Future< SeilonPermissionReport> -
override
-
startScan(
int durationSeconds) → Future< void> -
override
-
stopScan(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited