SeilonVoicePluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- SeilonVoicePluginPlatform
- Implementers
Constructors
Properties
-
events
→ Stream<
SeilonSdkEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPermissions(
SeilonPermissionOperation operation) → Future< SeilonPermissionReport> -
clearLogs(
) → Future< void> -
close(
) → Future< void> -
connect(
String deviceId) → Future< SeilonSessionHandle> -
disconnect(
) → Future< void> -
initialize(
SeilonSdkConfig config) → Future< void> -
invokeNetwork(
String method, [Map< String, Object?> arguments = const <String, Object?>{}]) → Future<Object?> -
invokeSession(
String method, int sessionToken, [Map< String, Object?> arguments = const <String, Object?>{}]) → Future<Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermissions(
SeilonPermissionOperation operation) → Future< SeilonPermissionReport> -
startScan(
int durationSeconds) → Future< void> -
stopScan(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SeilonVoicePluginPlatform
-
getter/setter pair